@@ -29,6 +29,11 @@ pub enum Segment{
     Nil,
 }
 
+#[derive(Clone, Debug, PartialEq)]
+pub enum AkitaKeyword{
+    SqlExtenssion(String),
+}
+
 #[derive(Clone, Debug)]
 pub enum SegmentType{
     GroupBy,
@@ -192,6 +197,15 @@ impl ToSegment for String
     }
 }
 
+impl ToSegment for AkitaKeyword
+{
+    fn to_segment(&self) -> Segment {
+        match self {
+            AkitaKeyword::SqlExtenssion(ref ext) => Segment::Extenssion(ext.to_string()),
+        }
+    }
+}
+
 impl<T> From<T> for Segment
 where
     T: ToSegment,
